program define power_cmd_multreg, rclass
  version 13.1
  syntax , r2(real) n(integer) [ k(integer 1) Alpha(string) ]

  if ("`alpha'" == "") local alpha 0.05

  * r2 has to be between 0 and 1
  if `r2' <= 0 {
    display as error "The R-square must be larger than 0."
    display as error "That is: r2() must be larger than 0."
    error 198
  }

  if `r2' >= 1 {
    display as error "The R-square must be less than 1."
    display as error "That is: r2() must be less than 1."
    error 198
  }

  * K must be at least 1
  if `k' < 1 {
    display as error "The number of predictors must be at least 1."
    display as error "k() must be at least 1."
    error 198
  }

  * Load up macros to call same code as nestreg
  local r2f = `r2' // r2 full model
  local r2r = 0    // r2 reduced model
  local kf  = `k'  // k  full model
  local kr  = 0    // k  reduced model

  *****************************************
  * BEGIN SAME CODE AS NESTREG
  *****************************************
  local dfnum  = `kf' - `kr'                               // Note not -1 because of constant term
  local dfden  = `n' - `kf' - 1                            // df error, N - K - 1
  local f2     = (`r2f'-`r2r')/(1-`r2f')                   // f2 
  local lambda = `n'*`f2'                                  // Lambda from Cohen 1988
  local fcrit  = invFtail(`dfnum',`dfden', `alpha')        // F Critical for dfnum, dfden, alpha
  local power  = nFtail(`dfnum',`dfden',`lambda',`fcrit')  // Power using non-centrality parameter lambda
  *****************************************
  * END SAME CODE AS NESTREG
  *****************************************

  return scalar power = `power'
  return scalar N = `n'
  return scalar alpha = `alpha'
  return scalar r2 = `r2'
  return scalar k = `k'

end
