program define power_cmd_nestreg, rclass
  version 13.1
  syntax , r2f(real) kf(integer) r2r(real) kr(integer) n(integer) ///
          [ Alpha(string) ]

  if ("`alpha'" == "") local alpha 0.05

  * r2FULL has to be between 0 and 1
  if `r2f' <= 0 {
    display as error "The R-square Full must be larger than 0."
    display as error "That is: r2f() must be larger than 0."
    error 198
  }

  if `r2f' >= 1 {
    display as error "The R-square Full must be less than 1."
    display as error "That is: r2f() must be less than 1."
    error 198
  }

  * r2FULL must be greater than r2REDUCED
  if `r2f' <= `r2r' {
    display as error "The R-square Full must be larger than the R-square Reduced."
    display as error "That is: r2f() must be larger than r2r()"
    error 198
  }

  * KF must be at least 1
  if `kf' < 1 {
    display as error "The number of predictors in the full model must be at least 1."
    display as error "kf() must be at least 1."

    error 198
  }

  * KR cannot be less than 0
  if `kr' < 0 {
    display as error "The number of predictors in the reduced model cannot be negative."
    display as error "kr() must be at least 0."

    error 198
  }
  
  * KF must be larger than KR
  if `kf' <= `kr' {
    display as error "The number of predictors in the full model must be larger than"
    display as error "the number of predictors in the reduced model."
    display as error "kf() must be greater than kr()."

    error 198
  }

  *****************************************
  * BEGIN SAME CODE AS NESTREG
  *****************************************
  local dfnum  = `kf' - `kr'                               // Note not -1 because of constant term
  local dfden  = `n' - `kf' - 1                            // df error, N - K - 1
  local f2     = (`r2f'-`r2r')/(1-`r2f')                   // f2 
  local lambda = `n'*`f2'                                  // Lambda from Cohen 1988
  local fcrit  = invFtail(`dfnum',`dfden', `alpha')        // F Critical for dfnum, dfden, alpha
  local power  = nFtail(`dfnum',`dfden',`lambda',`fcrit')  // Power using non-centrality parameter lambda
  *****************************************
  * END SAME CODE AS NESTREG
  *****************************************

  return scalar power = `power'
  return scalar N = `n'
  return scalar alpha = `alpha'
  return scalar r2f = `r2f'
  return scalar r2r = `r2r'
  return scalar kf = `kf'
  return scalar kr = `kr'
end
